==> walletpackage-1.0.25.tar.gz: test/walletpackage_test.dart <==
import 'package:walletpackage/walletpackage.dart';

Future<void> main() async {
//  testCreateMnemonicAndAddress();
//  testChangePassword();
//   testImportMnemonicAndAddress();

//  testCreateErc20Transaction();
//      .then((value) => {testSignEusdtTransaction(value)});
//  testCreateOmniTransaction();
//      .then((value) => {testSignUsdtTransaction(value)});

//  testRsa();

  // testImportMnemonicAndAddress(
  //     testMnemonic:
  //         'almost quantum option rail milk million office today humor monster fashion front');

  // testImportMnemonicAndAddress(
  //     testMnemonic:
  //         'truly deal badge crouch affair jay talk rib pumpkin eight fade grunt');

  // testImportMnemonicAndAddress(
  //     testMnemonic:
  //         'canoe pencil identify own canal rigid keen unique tattoo stadium family damp');

  testCreateEthTransaction().then((value) => {testSignEthTransaction(value)});
}

Future<void> testRsa() async {
  var rsa = await RsaProxy.create();
  print(rsa.publicKey);
  print(rsa.privateKey);
  String message = '123456abc';
  String signedText = await rsa.sign(message);
  print(signedText);
  bool verified = await rsa.verifySignature(message, signedText);
  print(verified);
}

Future<void> testSignUsdtTransaction(Object transaction) async {
  String type = 'USDT';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"4878f68b566980ace37743781ac45fad"},"ciphertext":"ca189c3911d1e5e14c6706e31dc3736229572c9866eecfef7c6e2a8755fb0fbcc5de0cb299645b446d2d5bc9b2407e617bb6c10a727e06b4dd07f072690c8277","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"2e0c841f726fcc6b4794c1561a1b4d7ea3d60fa6f73494ba3476e341211fe799"},"mac":"92d5a8b64775db2eeeb70d45683b20016844b2d81a11935c46d047af904c4be4"},"id":"a09a0bba-e9e2-474b-9867-186f48e2dfaa","version":3}';
  String passwd = '12345678';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateOmniTransaction() async {
  String from = '16ARP9AvHYnSPAmjbiV7SXzMzYpfL9ocoE';
  String to = '3Ft3P7BcpFKEm657GGUyYz9j6sk5HSuTWt';
  num value = 0.5;
  num fee = 0.00060333;
  String type = 'USDT';
  var transaction = await BitcoinTransaction.createOmniTransaction(
      from, to, value, fee,
      type: type);
  return transaction;
}

Future<void> testSignEthTransaction(Object transaction) async {
  String type = 'ETH';
  String keystore =
      //'{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
    '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"294f9c8aab9f0a25a496efd7917ea2b3"},"ciphertext":"a7f4e9b23eaf33b5f916b51deff2d66460a2762eb6ef5883c043787fab8cd2983fa7de260fc9910f6a0a84b6e91d25d254ef18222816c183393d9b714d3810df","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d0db43a5cc1ec326e4f9f569ffac20cf16dbf18d50604ccf1cbf9aff162042d2"},"mac":"1d7b0275ff71efd821e19dee5c1e0281e57a7f0f8e7137b588619f382174e85a"},"id":"5d7ea4eb-c8a5-4601-a5e2-5fbed3603548","version":3}';
  String passwd = '597095';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<void> testSignEusdtTransaction(Object transaction) async {
  String type = 'SIM';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
  String passwd = '12345678';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateEthTransaction() async {
  String from = '0x4Da2D8CDA7Bbe446C040f5DA854646D6116C984f';
  String to = '0xbE953993f9b3d4C11B18Ca5496e57C757669CEE8';
  num value = 0.400918209495353184;
  int gasPrice = 80000000000;
  int nonce = 50;
  String type = 'ETH';
  var transaction = await EthereumTransaction.createEthereumTransaction(
      from, to, value, gasPrice, nonce,
      type: type);
  return transaction;
}

Future<Object> testCreateErc20Transaction() async {
  String from = '0x48793114f5e43d190C2ad626406e4a860193084c';
  String to = '0x3db9f46631D1B478004213E4156D6902D73CD202';
  num value = 100;
  int gasPrice = 11000000000;
  int nonce = 0;
  String type = 'SIM';
  var transaction = await EthereumTransaction.createErc20Transaction(
      from, to, value, gasPrice, nonce,
      type: type);
  return transaction;
}

Future<void> testImportMnemonicAndAddress({String testMnemonic}) async {
  String mnemonic =
      'diagram frame frequent rain episode convince indoor thank retreat wheat vapor unusual';
  if (testMnemonic != null) {
    mnemonic = testMnemonic;
  }

  WalletData walletData = await WalletProxy.importMnemonicAndAddress(mnemonic);
  print('------------------------------------');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
  print('------------------------------------');
}

Future<void> testChangePassword() async {
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"6c02c795e7b3df21d7b88dee53a3e6bd"},"ciphertext":"658f02c82d551eae5bcec7beb7952d0ad8191f697c6b46e563179c2d8f4868304e08f60c0bd9c566c4aec35091fb4d4502c49f3f1d45d35279af68b84935f563","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"9bd25b612f58d361b1f69728dc3ee5fe3f22775ddc6a29531111b0be74a6e9b1"},"mac":"c2182716ff042d48d587a727bc9ca338bb27e902ed121acf7b3a9446d9aae0b7"},"id":"0bb8fb48-a218-44b2-97b7-a9d263bb71de","version":3}';
  String passwd = '123456';
  String newPasswd = '456789';
  String newKeystore =
      await WalletProxy.changePassword(keystore, passwd, newPasswd);
  print(newKeystore);
}

Future<void> testCreateMnemonicAndAddress() async {
  WalletData walletData = await WalletProxy.createMnemonicAndAddress('123456');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
}

==> walletpackage-1.1.0.tar.gz: test/walletpackage_test.dart <==
import 'package:walletpackage/walletpackage.dart';

Future<void> main() async {
  // testCreateMnemonicAndAddress();
  // testChangePassword();
  //  testImportMnemonicAndAddress();
  //
  // testCreateErc20Transaction();
  //     .then((value) => {testSignEusdtTransaction(value)});
  // testCreateOmniTransaction();
  //     .then((value) => {testSignUsdtTransaction(value)});
  //
  // testRsa();
  //
  // testImportMnemonicAndAddress(
  //     testMnemonic:
  //         'rib wonder notice early dance tag vehicle rug real matter seat basic');

  // testCreateEthTransaction().then((value) => {testSignEthTransaction(value)});
  // testCreateTrxTransaction().then((value) => {testSignTrxTransaction(value)});
  testCreateTrc20Transaction()
      .then((value) => {testSignTrc20Transaction(value)});
}

Future<Object> testCreateTrc20Transaction() async {
  String from = 'TGyS6Lj6CQy1XgMj56GeTuYPWER5JXDV5n';
  String to = 'TVzLYRd2FpTeohLEGx4zvM19JgeMYEQCWM';
  num value = 0.001;
  String refBlockHash =
      '0000000000b48fbc57b7c9cbaac744cfe4dc0e2fb455ae7c4a139d7f90b1c48d';
  String refBlockNum = '11833276';
  String type = 'TRCTUSDT';
  int feeLimit = 2000000;
  var transaction = await TronTransaction.createTrc20Transaction(
      from, to, value, refBlockHash, refBlockNum, feeLimit,
      type: type);
  return transaction;
}

Future<void> testSignTrc20Transaction(Object transaction) async {
  String type = 'TRCUSDT';
  String keystore =
      //'{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"294f9c8aab9f0a25a496efd7917ea2b3"},"ciphertext":"a7f4e9b23eaf33b5f916b51deff2d66460a2762eb6ef5883c043787fab8cd2983fa7de260fc9910f6a0a84b6e91d25d254ef18222816c183393d9b714d3810df","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d0db43a5cc1ec326e4f9f569ffac20cf16dbf18d50604ccf1cbf9aff162042d2"},"mac":"1d7b0275ff71efd821e19dee5c1e0281e57a7f0f8e7137b588619f382174e85a"},"id":"5d7ea4eb-c8a5-4601-a5e2-5fbed3603548","version":3}';
  String passwd = '597095';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateTrxTransaction() async {
  String from = 'TGyS6Lj6CQy1XgMj56GeTuYPWER5JXDV5n';
  String to = 'TVzLYRd2FpTeohLEGx4zvM19JgeMYEQCWM';
  num value = 0.001;
  String refBlockHash =
      '0000000000b48fbc57b7c9cbaac744cfe4dc0e2fb455ae7c4a139d7f90b1c48d';
  String refBlockNum = '11833276';
  String type = 'TRX';
  int feeLimit = 2000000;
  var transaction = await TronTransaction.createTrxTransaction(
      from, to, value, refBlockHash, refBlockNum, feeLimit,
      type: type);
  return transaction;
}

Future<void> testSignTrxTransaction(Object transaction) async {
  String type = 'TRX';
  String keystore =
      //'{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"294f9c8aab9f0a25a496efd7917ea2b3"},"ciphertext":"a7f4e9b23eaf33b5f916b51deff2d66460a2762eb6ef5883c043787fab8cd2983fa7de260fc9910f6a0a84b6e91d25d254ef18222816c183393d9b714d3810df","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d0db43a5cc1ec326e4f9f569ffac20cf16dbf18d50604ccf1cbf9aff162042d2"},"mac":"1d7b0275ff71efd821e19dee5c1e0281e57a7f0f8e7137b588619f382174e85a"},"id":"5d7ea4eb-c8a5-4601-a5e2-5fbed3603548","version":3}';
  String passwd = '597095';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<void> testRsa() async {
  var rsa = await RsaProxy.create();
  print(rsa.publicKey);
  print(rsa.privateKey);
  String message = '123456abc';
  String signedText = await rsa.sign(message);
  print(signedText);
  bool verified = await rsa.verifySignature(message, signedText);
  print(verified);
}

Future<void> testSignUsdtTransaction(Object transaction) async {
  String type = 'USDT';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"4878f68b566980ace37743781ac45fad"},"ciphertext":"ca189c3911d1e5e14c6706e31dc3736229572c9866eecfef7c6e2a8755fb0fbcc5de0cb299645b446d2d5bc9b2407e617bb6c10a727e06b4dd07f072690c8277","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"2e0c841f726fcc6b4794c1561a1b4d7ea3d60fa6f73494ba3476e341211fe799"},"mac":"92d5a8b64775db2eeeb70d45683b20016844b2d81a11935c46d047af904c4be4"},"id":"a09a0bba-e9e2-474b-9867-186f48e2dfaa","version":3}';
  String passwd = '12345678';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateOmniTransaction() async {
  String from = '16ARP9AvHYnSPAmjbiV7SXzMzYpfL9ocoE';
  String to = '3Ft3P7BcpFKEm657GGUyYz9j6sk5HSuTWt';
  num value = 0.5;
  num fee = 0.00060333;
  String type = 'USDT';
  var transaction = await BitcoinTransaction.createOmniTransaction(
      from, to, value, fee,
      type: type);
  return transaction;
}

Future<void> testSignEthTransaction(Object transaction) async {
  String type = 'ETH';
  String keystore =
      //'{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"294f9c8aab9f0a25a496efd7917ea2b3"},"ciphertext":"a7f4e9b23eaf33b5f916b51deff2d66460a2762eb6ef5883c043787fab8cd2983fa7de260fc9910f6a0a84b6e91d25d254ef18222816c183393d9b714d3810df","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d0db43a5cc1ec326e4f9f569ffac20cf16dbf18d50604ccf1cbf9aff162042d2"},"mac":"1d7b0275ff71efd821e19dee5c1e0281e57a7f0f8e7137b588619f382174e85a"},"id":"5d7ea4eb-c8a5-4601-a5e2-5fbed3603548","version":3}';
  String passwd = '597095';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<void> testSignEusdtTransaction(Object transaction) async {
  String type = 'SIM';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"9229369ffcb7b34bb5edee5d15cefcb2"},"ciphertext":"a383dd63b75ae772a35a324b0dbb1540b6a878f6009418a32e254f0261ab44aab4f0a86ff11cf7df2999e9753dfd8ee0e62e18fc351a3bf9136fc10abc98e36b","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"d1ccede5158ca825b045a453c3f6b659ee45e14620f06ea936e93731ee9cf80b"},"mac":"71884c7122acadad751d3c54692a4c6145b85df94b572f94a26e93a1e9d5baad"},"id":"121ce5d1-bf44-4bde-a864-5e28c3e6dac6","version":3}';
  String passwd = '12345678';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateEthTransaction() async {
  String from = '0x4Da2D8CDA7Bbe446C040f5DA854646D6116C984f';
  String to = '0xbE953993f9b3d4C11B18Ca5496e57C757669CEE8';
  num value = 0.400918209495353184;
  int gasPrice = 80000000000;
  int nonce = 50;
  String type = 'ETH';
  var transaction = await EthereumTransaction.createEthereumTransaction(
      from, to, value, gasPrice, nonce,
      type: type);
  return transaction;
}

Future<Object> testCreateErc20Transaction() async {
  String from = '0x48793114f5e43d190C2ad626406e4a860193084c';
  String to = '0x3db9f46631D1B478004213E4156D6902D73CD202';
  num value = 100;
  int gasPrice = 11000000000;
  int nonce = 0;
  String type = 'SIM';
  var transaction = await EthereumTransaction.createErc20Transaction(
      from, to, value, gasPrice, nonce,
      type: type);
  return transaction;
}

Future<void> testImportMnemonicAndAddress({String testMnemonic}) async {
  String mnemonic = '';
  if (testMnemonic != null) {
    mnemonic = testMnemonic;
  } else {
    WalletData walletData =
        await WalletProxy.createMnemonicAndAddress('123456');
    print(walletData.mnemonic);
    mnemonic = walletData.mnemonic;
  }

  WalletData walletData = await WalletProxy.importMnemonicAndAddress(mnemonic);
  print('------------------------------------');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
  print('------------------------------------');
}

Future<void> testChangePassword() async {
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"6c02c795e7b3df21d7b88dee53a3e6bd"},"ciphertext":"658f02c82d551eae5bcec7beb7952d0ad8191f697c6b46e563179c2d8f4868304e08f60c0bd9c566c4aec35091fb4d4502c49f3f1d45d35279af68b84935f563","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"9bd25b612f58d361b1f69728dc3ee5fe3f22775ddc6a29531111b0be74a6e9b1"},"mac":"c2182716ff042d48d587a727bc9ca338bb27e902ed121acf7b3a9446d9aae0b7"},"id":"0bb8fb48-a218-44b2-97b7-a9d263bb71de","version":3}';
  String passwd = '123456';
  String newPasswd = '456789';
  String newKeystore =
      await WalletProxy.changePassword(keystore, passwd, newPasswd);
  print(newKeystore);
}

Future<void> testCreateMnemonicAndAddress() async {
  WalletData walletData = await WalletProxy.createMnemonicAndAddress('123456');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
}
